BlockNoteCustomInlineContent class

Custom inline content.

Inheritance

Constructors

BlockNoteCustomInlineContent({required String type, List<BlockNoteStyledText>? content, Map<String, dynamic> props = const <String, dynamic>{}})
const

Properties

content List<BlockNoteStyledText>?
Optional styled text content.
final
hashCode int
The hash code for this object.
no setteroverride
props Map<String, dynamic>
Custom properties for the inline content.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The custom inline content type.
final

Methods

copyWith({String? type, Object? content = kUnset, Map<String, dynamic>? props}) BlockNoteCustomInlineContent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this inline content to JSON.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override