BlockNoteStyledText class

BlockNote styled text content.

Constructors

BlockNoteStyledText({String type = 'text', required String text, Map<String, dynamic>? styles})
Creates a new styled text instance.
const
BlockNoteStyledText.fromJson(Map<String, dynamic> json)
Creates a BlockNoteStyledText from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Map<String, dynamic>?
Optional text styles (bold, italic, underline, textColor, backgroundColor, etc.). Can contain boolean values (bold, italic, underline, strike) and string values (textColor, backgroundColor).
final
text String
The text content.
final
type String
The type of inline content.
final

Methods

copyWith({String? type, String? text, Object? styles = kUnset}) BlockNoteStyledText
Creates a copy with optional updates.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this styled text to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override