BlockNoteTextContent class

Text inline content.

Inheritance

Constructors

BlockNoteTextContent({String type = 'text', required String text, Map<String, dynamic>? styles})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Map<String, dynamic>?
Optional text styles.
final
text String
The text content.
final
type String
The type of inline content.
final

Methods

copyWith({String? type, String? text, Object? styles = kUnset}) BlockNoteTextContent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this inline content to JSON.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override