BlockNoteLinkContent class
Link inline content.
- Inheritance
-
- Object
- BlockNoteInlineContent
- BlockNoteLinkContent
Constructors
-
BlockNoteLinkContent({String type = 'link', required List<
BlockNoteStyledText> content, required String href}) -
const
Properties
-
content
→ List<
BlockNoteStyledText> -
The styled text content inside the link.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- href → String
-
The link href.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of inline content.
final
Methods
-
copyWith(
{String? type, List< BlockNoteStyledText> ? content, String? href}) → BlockNoteLinkContent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this inline content to JSON.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override